# Installing the required packages for this analysis. 
# This will only need to be done once.
# Uncomment the code below to run the install.packages function.
# install.packages(c("eRm", "dplyr", "ggplot2", "pairwise", "TAM", "psych"))

# Load the packages required for the analysis
library(eRm)

# Reading in the comma-seperated data set
df <- read.csv("ARMChapter7.csv", header = TRUE, sep = ";") 

# Select the 18 columns of df where the Pendulum items are at
pend_items <- df[,2:19]
# Looking at the first five rows of the Pendulum dataframe
head(pend_items)

# Look at column names of the data
colnames(pend_items)

# Fit a Partial Credit Model for the BLOT data
fit_pcm_pend <- PCM(pend_items)

# Look at Order.length's responses
pend_items$Order.lengths

# Look at Test.weight's responses
pend_items$Tests.weights
# Look at a table of the responses
table(pend_items$Tests.weights)

sapply(X = pend_items, FUN = table)

# Estimating person parameters for each observed raw score. 
pparameters_pend <- person.parameter(fit_pcm_pend) 
# Estimate item parameters
item_fit_pend <- itemfit(pparameters_pend) 
print(item_fit_pend)

print(item_fit_pend, sort_by = "outfit_MSQ")

thresholds(fit_pcm_pend)

# Wright map
plotPImap(fit_pcm_pend, irug = TRUE, sort = TRUE) 

# Run the Wright map without "Test.weights"
plotPImap(fit_pcm_pend, irug = TRUE, sort = TRUE,
          item.subset = c(1:6,8:17)) 


# Pathway map with 95% confidence intervals for the item parameters
plotPWmap(fit_pcm_pend, itemCI = list(gamma=0.95,col="red",lty="dotted"))

# Re-estimate the model without the eighth item ("Test.weights")
new_fit_pcm_pend <- PCM(pend_items[,-c(8)])
# Run the pathway map on the new model
plotPWmap(new_fit_pcm_pend, itemCI = list())
